CpuInterrupt

Enum CpuInterrupt 

#[repr(u32)]
pub enum CpuInterrupt {
Show 24 variants Interrupt0LevelPriority1 = 0, Interrupt1LevelPriority1 = 1, Interrupt2LevelPriority1 = 2, Interrupt3LevelPriority1 = 3, Interrupt4LevelPriority1 = 4, Interrupt5LevelPriority1 = 5, Interrupt6Timer0Priority1 = 6, Interrupt7SoftwarePriority1 = 7, Interrupt8LevelPriority1 = 8, Interrupt9LevelPriority1 = 9, Interrupt10EdgePriority1 = 10, Interrupt11ProfilingPriority3 = 11, Interrupt12LevelPriority1 = 12, Interrupt13LevelPriority1 = 13, Interrupt15Timer1Priority3 = 15, Interrupt17LevelPriority1 = 17, Interrupt18LevelPriority1 = 18, Interrupt19LevelPriority2 = 19, Interrupt20LevelPriority2 = 20, Interrupt21LevelPriority2 = 21, Interrupt22EdgePriority3 = 22, Interrupt23LevelPriority3 = 23, Interrupt27LevelPriority3 = 27, Interrupt29SoftwarePriority3 = 29,
}
Available on crate feature unstable only.
Enumeration of available CPU interrupts

It’s possible to create one handler per priority level. (e.g level1_interrupt)

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Variants



Interrupt0LevelPriority1 = 0

Level-triggered interrupt with priority 1.



Interrupt1LevelPriority1 = 1

Level-triggered interrupt with priority 1.



Interrupt2LevelPriority1 = 2

Level-triggered interrupt with priority 1.



Interrupt3LevelPriority1 = 3

Level-triggered interrupt with priority 1.



Interrupt4LevelPriority1 = 4

Level-triggered interrupt with priority 1.



Interrupt5LevelPriority1 = 5

Level-triggered interrupt with priority 1.



Interrupt6Timer0Priority1 = 6

Timer 0 interrupt with priority 1.



Interrupt7SoftwarePriority1 = 7

Software-triggered interrupt with priority 1.



Interrupt8LevelPriority1 = 8

Level-triggered interrupt with priority 1.



Interrupt9LevelPriority1 = 9

Level-triggered interrupt with priority 1.



Interrupt10EdgePriority1 = 10

Edge-triggered interrupt with priority 1.



Interrupt11ProfilingPriority3 = 11

Profiling-related interrupt with priority 3.



Interrupt12LevelPriority1 = 12

Level-triggered interrupt with priority 1.



Interrupt13LevelPriority1 = 13

Level-triggered interrupt with priority 1.



Interrupt15Timer1Priority3 = 15

Timer 1 interrupt with priority 3.



Interrupt17LevelPriority1 = 17

Level-triggered interrupt with priority 1.



Interrupt18LevelPriority1 = 18

Level-triggered interrupt with priority 1.



Interrupt19LevelPriority2 = 19

Level-triggered interrupt with priority 2.



Interrupt20LevelPriority2 = 20

Level-triggered interrupt with priority 2.



Interrupt21LevelPriority2 = 21

Level-triggered interrupt with priority 2.



Interrupt22EdgePriority3 = 22

Edge-triggered interrupt with priority 3.



Interrupt23LevelPriority3 = 23

Level-triggered interrupt with priority 3.



Interrupt27LevelPriority3 = 27

Level-triggered interrupt with priority 3.



Interrupt29SoftwarePriority3 = 29

Software-triggered interrupt with priority 3.

Implementations

Source

impl CpuInterrupt

pub fn enable(self)

Enable the CPU interrupt

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn clear(self)

Clear the CPU interrupt status bit

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn priority(self) -> Priority

Get interrupt priority for the CPU

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.